function fBm=circFBM(n,h,tmax,sigma,seed) 
%
% ------------------------------------------------------------------------
%
% Input   :
%                       n : length of the discretized sample path 
%                       h : Hurst parameter, 0<h<1.
%
%
% Output  :
%
%            simulation of a standard fBm on the set {0,1/n,....,n-1/n}
%            by the method of circulant matrix. 
%
%
% Example :  fBm=circFBM( 1000 , 0.3 )
%
% Subroutine called : lineC
% 
% ------------------------------------------------------------------------
%
% References : 
%
%       1 - Wood and Chan (1994)
%       2 - Phd Thesis Coeurjolly (2000), Appendix A p.132 
%
% ------------------------------------------------------------------------

switch nargin
  case 2
    tmax = 1 ; 
    sigma = 1 ;
    seed = rand(1) * 1e6 ;
  case 3
    sigma = 1 ;
    seed = rand(1) * 1e6 ;
  case 4
    seed = rand(1) * 1e6 ;
end


% --------------------------------------------------------
% Construction of the first line of the circulant matrix C
% --------------------------------------------------------
m=2^(fix(log(n-1)/log(2)+1));
eigC=lineC(n,h,sigma,tmax,m);
% ----------------------------------------------
% research of the power of two (<2^18) such that
% C is definite positive
% ----------------------------------------------
eigC=fft(eigC);
while ((eigC<=0) & (m<2^17))
m=2*m;
eigC=lineC(n,h,sigma,tmax,m);
eigC=fft(eigC);
end
% -----------------------------------------------
% simulation of W=(Q)^t Z, where Z leads N(0,I_m)
% and	(Q)_{jk} = m^(-1/2) exp(-2i pi jk/m)
% -----------------------------------------------
randn('seed',seed);
ar=randn(m/2+1,1);
ai=randn(m/2+1,1);
ar(1)= sqrt(2) * ar(1);
ar(m/2+1)= sqrt(2) * ar(m/2+1);
ai(1)=0;
ai(m/2+1)=0;
ar=[ar(1:m/2+1); ar( m/2:-1:2 )];
aic=-ai;
ai=[ai(1:m/2+1); aic(m/2:-1:2)];
W=ar + i*ai;
% -------------------------
% reconstruction of the fGn
% -------------------------
W=sqrt(eigC').* W;
fGn=fft(W);
fGn=fGn/sqrt(2*m);
fGn=real(fGn);
fGn=fGn(1:n);
fBm=0.5*cumsum(fGn);
