function [a,b]=regression_elimination(x,y,SupOuInf,Sigma,Gamma,TolNum)

% REGRESSION_ELIMINATION
%   Evaluation de la liminf ou limsup par eliminations successives.
% --------------------------------------------------------------
% SYNTAX :
% [a,b]=regression_elimination(x,y,SupOuInf,Sigma,Gamma,TolNum)
% --------------------------------------------------------------
% INPUTS:
%   x           : Abscisses
%   y           : Ordonnes
%   SupOuInf    : 'lsup' si recherche de limsup, 'linf' sinon.
%   Point n limin si y(n)+TolNum+Sigma*sqrt(N)*n^Gamma est en dessous de la
%   droite de rgression.
% --------------------------------------------------------------
% OUTPUTS:
%   a           :Pente
%   b           :Valeur de la droite  l'origine: offset

% Valeurs par dfaut
if nargin<6;TolNum=[];end
if nargin<5;Gamma=[];end
if nargin<4;Sigma=[];end
if nargin<3;SupOuInf=[];end

if isempty(TolNum);TolNum=10^(-12);end
if isempty(Gamma);Gamma=0;end
if isempty(Sigma);Sigma=0;end
if isempty(SupOuInf);SupOuInf='linf';end

% Reshape x and y
x=shiftdim(x);
y=shiftdim(y);

% Computation
if strcmp(SupOuInf,'linf')    
    N=size(x,1);
    if N<2
        error('The regression needs more than one point');
    end
    while N>1
        [a,b]=monolr(x,y,'ls');
        indices=find(y+TolNum+Sigma*sqrt(N)*[1:N]'.^Gamma<a*x+b);
        y=y(indices);
        x=x(indices);
        N=size(x,1);
    end
elseif strcmp(SupOuInf,'lsup')
    [a,b]=regression_elimination(x,-y,'linf',Sigma,Gamma,TolNum);
    a=-a;b=-b;
else
    error('Troisime argument de regression_elimination:''lsup'' si recherche de limsup, ''linf'' sinon')
end